<?xml version="1.0" ?><!DOCTYPE TS><TS language="es_ES" version="2.1">
<context>
    <name>@default</name>
    <message>
        <source>Autohide idle time</source>
        <translation>Tiempo de inactividad de ocultado automático</translation>
    </message>
    <message numerus="yes">
        <source>%n second(s)</source>
        <translation><numerusform>%n segundo</numerusform><numerusform>%n segundos</numerusform></translation>
    </message>
    <message>
        <source>Buddies list</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>General</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Buddies window</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hide buddy list window when unused</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AutoHideConfigurationUiHandler</name>
    <message>
        <source>Don&apos;t hide</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>